==> wls-plugin-3.5.0-sources.jar: wls/ds/create-datasource.py <==
#
connectAndEdit()

datasourcePath = '/JDBCSystemResources/%s/JDBCResource/%s' % (deployed.name, deployed.name)

if exists(datasourcePath):
    print 'Modifying data source %s for target %s' % (deployed.name, deployed.container.name)
    setOrOverride = overrideWithWarning
else:
    print 'Creating data source %s for target %s' % (deployed.name, deployed.container.name)
    cmo.createJDBCSystemResource(deployed.name)
    setOrOverride = set

cd(datasourcePath)
setOrOverride('Name', deployed.name)

cd('/JDBCSystemResources/%s' % (deployed.name))
newTargets = []
for t in get('Targets'):
    newTargets.append(t)
newTargets.append(ObjectName(deployed.container.objectName))
set('Targets', jarray.array(newTargets, ObjectName))

cd('%s/JDBCDriverParams/%s' % (datasourcePath, deployed.name))
setOrOverride("Url", deployed.url)
setOrOverride("DriverName", deployed.driverName)
setOrOverride('Password', deployed.password)

cd('%s/JDBCDriverParams/%s/Properties/%s' % (datasourcePath, deployed.name, deployed.name))
if not exists('Properties/user'):
    cmo.createProperty('user')
cd('Properties/user')
setOrOverride("Value", deployed.username)

cd('%s/JDBCDataSourceParams/%s' % (datasourcePath, deployed.name))
setOrOverride('JNDINames', jarray.array(deployed.jndiNames.split(','), String))

#set extra values in any at this level
propsToSet = deployed.getExposedProperties()
for key, value in propsToSet.items():
    if value is not None and isinstance(value, DictionaryObject) == False:
        print 'setting %s with value %s' % (key, value)
        set(key, value)

# create all the nested objects like ConnectionPool, JDBCParams etc
nestedObjects = findAllNestedObjects(deployed)
for objectName, nestedObj in nestedObjects.items():
    path = '%s/%s/%s' % (datasourcePath, objectName, deployed.name)
    print 'cd to %s' %(path)
    cd(path)
    for propKey, propValue in nestedObj.__dict__.items():
        if propValue != None:
            print 'setting %s with value %s' %(propKey, propValue)
            setOrOverride(propKey, propValue)

# Set other properties on the JBDCDriverParams
if hasattr(deployed, 'properties') and deployed.properties is not None:
    for prop in deployed.properties.split(","):
      if(len(prop.split("=")) == 2):
        propKey = prop.split("=")[0]
        propVal = prop.split("=")[1]
        cd('%s/JDBCDriverParams/%s/Properties%s' % (datasourcePath, deployed.name, deployed.name))
        if not exists('Properties/%s' % (propKey)):
            cmo.createProperty(key)
        cd('Properties/%s' % (propKey))
        setOrOverride("Value", val)

saveAndExit()

==> wls-plugin-3.6.0-sources.jar: wls/ds/create-datasource.py <==
#
connectAndEdit()

datasourcePath = '/JDBCSystemResources/%s/JDBCResource/%s' % (deployed.name, deployed.name)

if exists(datasourcePath):
    print 'Modifying data source %s for target %s' % (deployed.name, deployed.container.name)
    setOrOverride = overrideWithWarning
else:
    print 'Creating data source %s for target %s' % (deployed.name, deployed.container.name)
    cmo.createJDBCSystemResource(deployed.name)
    setOrOverride = set

cd(datasourcePath)
setOrOverride('Name', deployed.name)

cd('/JDBCSystemResources/%s' % (deployed.name))
newTargets = []
for t in get('Targets'):
    newTargets.append(t)
newTargets.append(ObjectName(deployed.container.objectName))
set('Targets', jarray.array(newTargets, ObjectName))

cd('%s/JDBCDriverParams/%s' % (datasourcePath, deployed.name))
setOrOverride("Url", deployed.url)
setOrOverride("DriverName", deployed.driverName)
setOrOverride('Password', deployed.password)

cd('%s/JDBCDriverParams/%s/Properties/%s' % (datasourcePath, deployed.name, deployed.name))
if not exists('Properties/user'):
    cmo.createProperty('user')
cd('Properties/user')
setOrOverride("Value", deployed.username)

cd('%s/JDBCDataSourceParams/%s' % (datasourcePath, deployed.name))
setOrOverride('JNDINames', jarray.array(deployed.jndiNames.split(','), String))

#set extra values in any at this level
propsToSet = deployed.getExposedProperties()
for key, value in propsToSet.items():
    if value is not None and isinstance(value, DictionaryObject) == False:
        print 'setting %s with value %s' % (key, value)
        set(key, value)

# create all the nested objects like ConnectionPool, JDBCParams etc
nestedObjects = findAllNestedObjects(deployed)
for objectName, nestedObj in nestedObjects.items():
    path = '%s/%s/%s' % (datasourcePath, objectName, deployed.name)
    print 'cd to %s' %(path)
    cd(path)
    for propKey, propValue in nestedObj.getExposedProperties().items():
        if propValue != None:
            print 'setting %s with value %s' %(propKey, propValue)
            setOrOverride(propKey, propValue)

# Set other properties on the JBDCDriverParams
if hasattr(deployed, 'properties') and deployed.properties is not None:
    for propKey, propVal in deployed.properties.items():
        cd('%s/JDBCDriverParams/%s/Properties%s' % (datasourcePath, deployed.name, deployed.name))
        if not exists('Properties/%s' % (propKey)):
            cmo.createProperty(propKey)
        cd('Properties/%s' % (propKey))
        setOrOverride("Value", propVal)

saveAndExit()
